build.nblist: Generate spatial weights from prabclus neighborhood list
Description
This generates a listw-object as needed for estimation of a
simultaneous autoregression model in package spdep from a
neighborhood list of the type generated in prabinit.
Usage
build.nblist(prabobj,prab01=NULL,style="C")
Arguments
prabobj
object of class prab.
prab01
presence-absence matrix of same dimensions than the
abundance matrix of prabobj. This specifies the presences and
absences on which the presence/absence step of abundance-based tests
is based (see details). If NULL (which i
style
can take values "W", "B", "C", "U", and "S" though tests
suggest that "C" should be chosen. See nb2listw.
Value
A 'listw' object with the following members:
stylesee above.
neighboursthe neighbours list in spdep-format.
weightsthe weights for the neighbours and chosen style, with
attributes set to report the type of relationships (binary or
general, if general the form of the glist argument), and
style as above.