Learn R Programming

prabclus (version 2.2-4)

geo2neighbor: Neighborhood list from geographical distance

Description

Generates a neighborhood list as required by prabinit from a matrix of geographical distances.

Usage

geo2neighbor(geodist,cut=0.1*max(geodist))

Arguments

geodist
dist-object or symmetric non-negative matrix. Geographical distances between regions.
cut
non-negative numerical. All pairs of regions with distance<=cut< code=""> are treated as neighbors.

Value

  • A list of integer vectors, giving the set of neighbors for every region.

Examples

Run this code
data(waterdist)
geo2neighbor(waterdist)

Run the code above in your browser using DataLab