Learn R Programming

prabclus (version 2.0-2)

kykladspecreg: Snail presence-absence data from Aegean sea

Description

0-1-matrix where rows are snail species and columns are islands in the Aegean sea. An entry of 1 means that the species is present in the region.

Usage

data(kykladspecreg)

Arguments

format

A 0-1 matrix with 80 rows and 34 columns.

source

Hausdorf, B. and Hennig, C. (2002) Biogeographical tests of the Importance of Vicariance in the Diversification of Mediterranean Land Snails. Submitted.

Details

Reads from example data file kykladspecreg.dat.

See Also

nb provides neighborhood information about the 34 islands.

Examples

Run this code
data(kykladspecreg)
# Note: If you do not use the installed package, replace this by
# kykladspecreg <- read.table("(path/)kykladspecreg.dat")

Run the code above in your browser using DataLab