Learn R Programming

prabclus (version 2.2-2)

kykladspecreg: Snail presence-absence data from Aegean sea

Description

0-1-matrix where rows are snail species and columns are islands in the Aegean sea. An entry of 1 means that the species is present in the region.

Usage

data(kykladspecreg)

Arguments

format

A 0-1 matrix with 80 rows and 34 columns.

source

B. Hausdorf and C. Hennig (2005) The influence of recent geography, palaeography and climate on the composition of the faune of the central Aegean Islands. Biological Journal of the Linnean Society 84, 785-795.

Details

Reads from example data file kykladspecreg.dat.

See Also

nb provides neighborhood information about the 34 islands. waterdist provides a geographical distance matrix between the islands.

Examples

Run this code
data(kykladspecreg)

Run the code above in your browser using DataLab